@@ -6,5 +6,5 @@ from .abstract import Abstract
 class Project(Abstract):
   '''Webapp Project class'''
   def __init__(self, cfg):
-    super().__init__(cfg)
+    super(Project, self).__init__(cfg)
     self.endpoint += 'projects/'
